
.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_max7219.max7219
   :members:
   :show-inheritance:

.. automodule:: adafruit_max7219.matrices
   :members:

.. automodule:: adafruit_max7219.bcddigits
   :members:
